/**
 * CasingMaster class provides methods for converting strings
 * between different case formats such as camelCase, snake_case, PascalCase, etc.
 */
export declare class CasingMaster {
    /**
     * Converts the input string to camelCase.
     *
     * @example
     * CasingMaster.toCamelCase('hello world'); // 'helloWorld'
     *
     * @param input The string to be converted.
     * @returns The string in camelCase format.
     */
    static toCamelCase(input: string): string;
    /**
     * Converts the input string to snake_case.
     *
     * @example
     * CasingMaster.toSnakeCase('hello world'); // 'hello_world'
     *
     * @param input The string to be converted.
     * @returns The string in snake_case format.
     */
    static toSnakeCase(input: string): string;
    /**
     * Converts the input string to PascalCase.
     *
     * @example
     * CasingMaster.toPascalCase('hello world'); // 'HelloWorld'
     *
     * @param input The string to be converted.
     * @returns The string in PascalCase format.
     */
    static toPascalCase(input: string): string;
    /**
     * Converts the input string to kebab-case.
     *
     * @example
     * CasingMaster.toKebabCase('hello world'); // 'hello-world'
     *
     * @param input The string to be converted.
     * @returns The string in kebab-case format.
     */
    static toKebabCase(input: string): string;
    /**
     * Converts the input string to SCREAMING_SNAKE_CASE.
     *
     * @example
     * CasingMaster.toScreamingSnakeCase('hello world'); // 'HELLO_WORLD'
     *
     * @param input The string to be converted.
     * @returns The string in SCREAMING_SNAKE_CASE format.
     */
    static toScreamingSnakeCase(input: string): string;
    /**
     * Converts the input string to Sentence case.
     *
     * @example
     * CasingMaster.toSentenceCase('HELLO WORLD'); // 'Hello world'
     *
     * @param input The string to be converted.
     * @returns The string in Sentence case format.
     */
    static toSentenceCase(input: string): string;
    /**
     * Converts the input string to Title Case.
     *
     * @example
     * CasingMaster.toTitleCase('hello world'); // 'Hello World'
     *
     * @param input The string to be converted.
     * @returns The string in Title Case format.
     */
    static toTitleCase(input: string): string;
    /**
     * Smart case converter that allows converting to a target case format.
     *
     * @example
     * CasingMaster.smartCaseConvert('hello world', 'pascal'); // 'HelloWorld'
     *
     * @param input The string to be converted.
     * @param targetCase The case format to convert to.
     * @returns The converted string in the desired case format.
     */
    static smartCaseConvert(input: string, targetCase: 'camel' | 'snake' | 'pascal' | 'kebab' | 'screaming-snake' | 'sentence' | 'title'): string;
    /**
     * Internal method to handle the logic for case conversion based on the target case.
     *
     * @param input The string to be converted.
     * @param targetCase The case format to convert to.
     * @returns The converted string.
     */
    private static convertCase;
    /**
     * Helper method to convert a string to camelCase.
     *
     * @param input The string to be converted.
     * @returns The camelCase formatted string.
     */
    private static toCamelCaseHelper;
    /**
     * Helper method to convert a string to snake_case.
     *
     * @param input The string to be converted.
     * @returns The snake_case formatted string.
     */
    private static toSnakeCaseHelper;
    /**
     * Helper method to convert a string to PascalCase.
     *
     * @param input The string to be converted.
     * @returns The PascalCase formatted string.
     */
    private static toPascalCaseHelper;
    /**
     * Helper method to convert a string to kebab-case.
     *
     * @param input The string to be converted.
     * @returns The kebab-case formatted string.
     */
    private static toKebabCaseHelper;
    /**
     * Helper method to convert a string to SCREAMING_SNAKE_CASE.
     *
     * @param input The string to be converted.
     * @returns The SCREAMING_SNAKE_CASE formatted string.
     */
    private static toScreamingSnakeCaseHelper;
    /**
     * Helper method to convert a string to Sentence case.
     *
     * @param input The string to be converted.
     * @returns The Sentence case formatted string.
     */
    private static toSentenceCaseHelper;
    /**
     * Helper method to convert a string to Title Case.
     *
     * @param input The string to be converted.
     * @returns The Title Case formatted string.
     */
    private static toTitleCaseHelper;
}
