/**
 * Options for customizing how initials are extracted or parsed.
 */
type InitialsOptions = {
    /**
     * The number of characters for the initials. Defaults to 2 if not provided.
     */
    length?: number;
    /**
     * A record of existing names mapped to their preferred initials.
     */
    existing?: Record<string, string>;
};
/**
 * Represents a parsed name with optional initials and email.
 */
interface ParsedName {
    name: string;
    initials?: string;
    email?: string;
}
export declare class InitialsMaster {
    private static readonly DEFAULT_INITIALS_LENGTH;
    private static readonly NON_LETTER_CHARACTERS;
    private static readonly ONLY_UPPERCASE_PATTERN;
    private static readonly INITIALS_IN_PARENTHESES_PATTERN;
    private static readonly EMAIL_PATTERN;
    private static readonly DOMAIN_IN_EMAIL_PATTERN;
    private static readonly EMAIL_EXTRACTION_PATTERN;
    private static readonly FIRST_LETTER_OF_WORDS_PATTERN;
    private static readonly NON_CHARACTER_PATTERN;
    /**
     * Extracts initials from a single or multiple names.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for extracting initials.
     * @returns Initials of the provided name(s).
     *
     * @example
     * // Extract initials for a single name
     * const initials = InitialsMaster.extractInitials('John Doe');
     * console.log(initials); // Output: 'JD'
     *
     * @example
     * // Extract initials for multiple names
     * const initials = InitialsMaster.extractInitials(['John Doe', 'Jane Smith']);
     * console.log(initials); // Output: ['JD', 'JS']
     *
     * @example
     * // Extract initials with a length of 3
     * const initials = InitialsMaster.extractInitials('John Doe', { length: 3 });
     * console.log(initials); // Output: 'Joh'
     */
    static extractInitials(nameOrNames: string | string[], options?: InitialsOptions): string | string[];
    /**
     * Adds initials to a name or an array of names.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for extracting initials.
     * @returns Names with appended initials.
     *
     * @example
     * // Add initials to a single name
     * const nameWithInitials = InitialsMaster.addInitialsTo('John Doe');
     * console.log(nameWithInitials); // Output: 'John Doe (JD)'
     *
     * @example
     * // Add initials to multiple names
     * const namesWithInitials = InitialsMaster.addInitialsTo(['John Doe', 'Jane Smith']);
     * console.log(namesWithInitials); // Output: ['John Doe (JD)', 'Jane Smith (JS)']
     */
    static addInitialsTo(nameOrNames: string | string[], options?: InitialsOptions): string | string[];
    /**
     * Parses a name or an array of names to extract components such as initials and email.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for parsing names.
     * @returns Parsed name(s) with possible initials and email.
     *
     * @example
     * // Parse a single name
     * const parsedName = InitialsMaster.parse('John Doe <john.doe@example.com>');
     * console.log(parsedName); // Output: { name: 'John Doe', initials: 'JD', email: 'john.doe@example.com' }
     *
     * @example
     * // Parse multiple names
     * const parsedNames = InitialsMaster.parse(['John Doe <john.doe@example.com>', 'Jane Smith']);
     * console.log(parsedNames); // Output: [{ name: 'John Doe', initials: 'JD', email: 'john.doe@example.com' }, { name: 'Jane Smith', initials: 'JS' }]
     */
    static parse(nameOrNames: string | string[], options?: InitialsOptions): ParsedName | ParsedName[];
    /**
     * Generates an acronym from a given phrase.
     *
     * @param phrase - The phrase from which to generate an acronym.
     * @returns A string representing the acronym of the phrase.
     * @example
     * const acronym = NameMaster.generateAcronym("As Soon As Possible"); // "ASAP"
     */
    static generateAcronym(phrase: string): string;
    /**
     * Extracts the first letter of each word in the given text.
     * @param text - The text to analyze.
     * @returns A string containing the first letter of each word.
     * @example
     * ```typescript
     * const result = InitialsMaster.getFirstLetterOfEachWord("Hello World Example");
     * console.log(result); // "HWE"
     * ```
     */
    static getFirstLetterOfEachWord(text: string): string;
    /**
     * Creates initials from the given phrase, optionally excluding certain words.
     * @param phrase - The phrase to analyze.
     * @param exclude - Optional list of words to exclude from the initials.
     * @returns A string containing the initials.
     * @example
     * ```typescript
     * const result = InitialsMaster.createInitialsFromPhrase("The Quick Brown Fox", ["the", "of"]);
     * console.log(result); // "QBF"
     * ```
     */
    static createInitialsFromPhrase(phrase: string, exclude?: string[]): string;
    /**
     * Creates an abbreviation for a full name using the initials of the first and middle names and the full last name.
     * @param fullName - The full name to abbreviate.
     * @returns An abbreviated form of the full name.
     * @example
     * ```typescript
     * const result = InitialsMaster.abbreviateName("John Michael Smith");
     * console.log(result); // "J.M.S."
     * ```
     */
    static abbreviateName(fullName: string): string;
    /**
     * Generates a custom acronym from a phrase, optionally including or excluding specific words.
     * @param phrase - The phrase to create an acronym from.
     * @param exclude - Optional list of words to exclude from the acronym.
     * @returns The acronym.
     * @example
     * ```typescript
     * const result = InitialsMaster.generateCustomAcronym("For Your Information", ["for", "your"]);
     * console.log(result); // "I"
     * ```
     */
    static generateCustomAcronym(phrase: string, exclude?: string[]): string;
    private static getInitialsForSingleName;
    private static getInitialsForMultipleNames;
    private static addInitialsToSingleName;
    private static addInitialsToMultipleNames;
    private static parseSingleName;
    private static parseMultipleNames;
    private static findPreferredInitials;
    private static extractParenthesizedInitials;
    private static extractEmail;
    private static cleanName;
    private static computePossibleInitials;
    private static getPossibleInitialsForWord;
    private static combineAll;
    private static formatParsedName;
    private static normalizeOptions;
}
export {};
