"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InitialsMaster = void 0;
class InitialsMaster {
    /**
     * Extracts initials from a single or multiple names.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for extracting initials.
     * @returns Initials of the provided name(s).
     *
     * @example
     * // Extract initials for a single name
     * const initials = InitialsMaster.extractInitials('John Doe');
     * console.log(initials); // Output: 'JD'
     *
     * @example
     * // Extract initials for multiple names
     * const initials = InitialsMaster.extractInitials(['John Doe', 'Jane Smith']);
     * console.log(initials); // Output: ['JD', 'JS']
     *
     * @example
     * // Extract initials with a length of 3
     * const initials = InitialsMaster.extractInitials('John Doe', { length: 3 });
     * console.log(initials); // Output: 'Joh'
     */
    static extractInitials(nameOrNames, options = {}) {
        const normalizedOptions = this.normalizeOptions(options);
        if (Array.isArray(nameOrNames)) {
            return this.getInitialsForMultipleNames(nameOrNames, normalizedOptions);
        }
        return this.getInitialsForSingleName(nameOrNames, normalizedOptions);
    }
    /**
     * Adds initials to a name or an array of names.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for extracting initials.
     * @returns Names with appended initials.
     *
     * @example
     * // Add initials to a single name
     * const nameWithInitials = InitialsMaster.addInitialsTo('John Doe');
     * console.log(nameWithInitials); // Output: 'John Doe (JD)'
     *
     * @example
     * // Add initials to multiple names
     * const namesWithInitials = InitialsMaster.addInitialsTo(['John Doe', 'Jane Smith']);
     * console.log(namesWithInitials); // Output: ['John Doe (JD)', 'Jane Smith (JS)']
     */
    static addInitialsTo(nameOrNames, options = {}) {
        const normalizedOptions = this.normalizeOptions(options);
        if (Array.isArray(nameOrNames)) {
            return this.addInitialsToMultipleNames(nameOrNames, normalizedOptions);
        }
        return this.addInitialsToSingleName(nameOrNames, normalizedOptions);
    }
    /**
     * Parses a name or an array of names to extract components such as initials and email.
     * @param nameOrNames A string or an array of strings containing the names.
     * @param options Custom options for parsing names.
     * @returns Parsed name(s) with possible initials and email.
     *
     * @example
     * // Parse a single name
     * const parsedName = InitialsMaster.parse('John Doe <john.doe@example.com>');
     * console.log(parsedName); // Output: { name: 'John Doe', initials: 'JD', email: 'john.doe@example.com' }
     *
     * @example
     * // Parse multiple names
     * const parsedNames = InitialsMaster.parse(['John Doe <john.doe@example.com>', 'Jane Smith']);
     * console.log(parsedNames); // Output: [{ name: 'John Doe', initials: 'JD', email: 'john.doe@example.com' }, { name: 'Jane Smith', initials: 'JS' }]
     */
    static parse(nameOrNames, options = {}) {
        const normalizedOptions = this.normalizeOptions(options);
        if (Array.isArray(nameOrNames)) {
            return this.parseMultipleNames(nameOrNames, normalizedOptions);
        }
        return this.parseSingleName(nameOrNames, normalizedOptions);
    }
    /**
     * Generates an acronym from a given phrase.
     *
     * @param phrase - The phrase from which to generate an acronym.
     * @returns A string representing the acronym of the phrase.
     * @example
     * const acronym = NameMaster.generateAcronym("As Soon As Possible"); // "ASAP"
     */
    static generateAcronym(phrase) {
        return phrase
            .split(' ')
            .filter((word) => word.length > 0) // Filter out any empty strings
            .map((word) => word.charAt(0).toUpperCase())
            .join('');
    }
    /**
     * Extracts the first letter of each word in the given text.
     * @param text - The text to analyze.
     * @returns A string containing the first letter of each word.
     * @example
     * ```typescript
     * const result = InitialsMaster.getFirstLetterOfEachWord("Hello World Example");
     * console.log(result); // "HWE"
     * ```
     */
    static getFirstLetterOfEachWord(text) {
        return text
            .split(/\s+/)
            .map((word) => word.charAt(0))
            .join('');
    }
    /**
     * Creates initials from the given phrase, optionally excluding certain words.
     * @param phrase - The phrase to analyze.
     * @param exclude - Optional list of words to exclude from the initials.
     * @returns A string containing the initials.
     * @example
     * ```typescript
     * const result = InitialsMaster.createInitialsFromPhrase("The Quick Brown Fox", ["the", "of"]);
     * console.log(result); // "QBF"
     * ```
     */
    static createInitialsFromPhrase(phrase, exclude = []) {
        const words = phrase
            .split(/\s+/)
            .filter((word) => !exclude.includes(word.toLowerCase()))
            .map((word) => word.charAt(0).toUpperCase());
        return words.join('');
    }
    /**
     * Creates an abbreviation for a full name using the initials of the first and middle names and the full last name.
     * @param fullName - The full name to abbreviate.
     * @returns An abbreviated form of the full name.
     * @example
     * ```typescript
     * const result = InitialsMaster.abbreviateName("John Michael Smith");
     * console.log(result); // "J.M.S."
     * ```
     */
    static abbreviateName(fullName) {
        const parts = fullName.split(/\s+/);
        if (parts.length < 2)
            return fullName; // Not enough parts to abbreviate
        const initials = parts
            .slice(0, -1)
            .map((part) => part.charAt(0).toUpperCase())
            .join('.');
        const lastName = parts[parts.length - 1];
        return `${initials}.${lastName.charAt(0).toUpperCase()}.`;
    }
    /**
     * Generates a custom acronym from a phrase, optionally including or excluding specific words.
     * @param phrase - The phrase to create an acronym from.
     * @param exclude - Optional list of words to exclude from the acronym.
     * @returns The acronym.
     * @example
     * ```typescript
     * const result = InitialsMaster.generateCustomAcronym("For Your Information", ["for", "your"]);
     * console.log(result); // "I"
     * ```
     */
    static generateCustomAcronym(phrase, exclude = []) {
        const words = phrase
            .split(/\s+/)
            .filter((word) => !exclude.includes(word.toLowerCase()))
            .map((word) => word.charAt(0).toUpperCase());
        return words.join('');
    }
    static getInitialsForSingleName(name, options) {
        var _a;
        const length = options.length;
        const initials = this.findPreferredInitials(name, options);
        if (initials)
            return initials;
        name = this.cleanName(name);
        if (!name)
            return '';
        // Get all matches for the first letter of each word
        const matches = ((_a = name.match(this.FIRST_LETTER_OF_WORDS_PATTERN)) === null || _a === void 0 ? void 0 : _a.map((match) => match[match.length - 1])) || [];
        // Join the first letters first, and then add more characters from words if length exceeds the number of words
        if (matches.length >= length) {
            return matches.slice(0, length).join('');
        }
        // If there aren't enough initials, start taking more characters from words
        let remainingLength = length - matches.length;
        const words = name.split(' ').filter(Boolean);
        let result = matches.join('');
        for (let i = 0; i < words.length && remainingLength > 0; i++) {
            const remainingChars = words[i].slice(1, remainingLength + 1);
            result += remainingChars;
            remainingLength -= remainingChars.length;
        }
        return result;
    }
    static getInitialsForMultipleNames(names, options) {
        return names.map((name) => this.getInitialsForSingleName(name, options));
    }
    static addInitialsToSingleName(name, options) {
        const parsedName = this.parseSingleName(name, options);
        return this.formatParsedName(parsedName);
    }
    static addInitialsToMultipleNames(names, options) {
        return this.parseMultipleNames(names, options).map(this.formatParsedName);
    }
    static parseSingleName(name, options) {
        const email = this.extractEmail(name);
        if (email) {
            // Remove the email from the name string
            name = name.replace(email, '').trim();
        }
        const initials = this.findPreferredInitials(name, options) || this.getInitialsForSingleName(name, options);
        // Construct the parsed name object, omitting 'email' if it's undefined
        const parsedName = { name: this.cleanName(name), initials };
        if (email) {
            parsedName.email = email;
        }
        return parsedName;
    }
    static parseMultipleNames(names, options) {
        return names.map((name) => this.parseSingleName(name, options));
    }
    static findPreferredInitials(name, options) {
        var _a;
        return ((_a = options.existing) === null || _a === void 0 ? void 0 : _a[name]) || this.extractParenthesizedInitials(name) || '';
    }
    static extractParenthesizedInitials(name) {
        const match = name.match(this.INITIALS_IN_PARENTHESES_PATTERN);
        return match ? match[1].trim() : '';
    }
    static extractEmail(name) {
        const match = name.match(this.EMAIL_EXTRACTION_PATTERN);
        return match ? match[0] : undefined;
    }
    static cleanName(name) {
        return name.replace(this.NON_CHARACTER_PATTERN, ' ').trim();
    }
    static computePossibleInitials(name) {
        const words = name.split(' ').filter(Boolean);
        const initialsArray = words.map((word) => this.getPossibleInitialsForWord(word));
        return this.combineAll(initialsArray);
    }
    static getPossibleInitialsForWord(word) {
        const options = [];
        for (let i = word.length; i > 0; i--) {
            options.push(word.slice(0, i));
        }
        return options;
    }
    static combineAll(arrays) {
        if (!arrays.length)
            return [];
        const [firstArray, ...restArrays] = arrays;
        if (!restArrays.length)
            return firstArray;
        const combinations = [];
        firstArray.forEach((prefix) => {
            this.combineAll(restArrays).forEach((suffix) => combinations.push(prefix + suffix));
        });
        return combinations;
    }
    static formatParsedName({ name, initials, email }) {
        const nameWithInitials = initials ? `${name} (${initials})` : name;
        return email ? `${nameWithInitials} <${email}>` : nameWithInitials;
    }
    static normalizeOptions(options) {
        var _a, _b;
        return {
            length: (_a = options.length) !== null && _a !== void 0 ? _a : this.DEFAULT_INITIALS_LENGTH,
            existing: (_b = options.existing) !== null && _b !== void 0 ? _b : {},
        };
    }
}
exports.InitialsMaster = InitialsMaster;
InitialsMaster.DEFAULT_INITIALS_LENGTH = 2;
// Regular expressions for extracting initials
InitialsMaster.NON_LETTER_CHARACTERS = ' -\\/:-@\\[-`\\{-\\~';
InitialsMaster.ONLY_UPPERCASE_PATTERN = /^[A-Z]+$/;
InitialsMaster.INITIALS_IN_PARENTHESES_PATTERN = /$begin:math:text$([^)]+)$end:math:text$/;
InitialsMaster.EMAIL_PATTERN = /^[^\s]+@[^\s]+$/;
InitialsMaster.DOMAIN_IN_EMAIL_PATTERN = /@[^\s]+/;
InitialsMaster.EMAIL_EXTRACTION_PATTERN = /[\w._-]+@[\w.-]+[\w]/g;
InitialsMaster.FIRST_LETTER_OF_WORDS_PATTERN = new RegExp(`(^|[${InitialsMaster.NON_LETTER_CHARACTERS}])[^${InitialsMaster.NON_LETTER_CHARACTERS}]`, 'g');
InitialsMaster.NON_CHARACTER_PATTERN = new RegExp(`[${InitialsMaster.NON_LETTER_CHARACTERS}]`, 'g');
