/**
 * ManipulationMaster class provides various string manipulation utilities
 * such as trimming, collapsing spaces, extracting substrings, and more.
 */
export declare class ManipulationMaster {
    /**
     * Extracts the string between two given substrings.
     *
     * @example
     * ManipulationMaster.between('Hello [World]!', '[', ']'); // 'World'
     *
     * @param input The full input string.
     * @param left The substring that marks the start of the extraction.
     * @param right The substring that marks the end of the extraction.
     * @returns The string between the left and right substrings.
     */
    static between(input: string, left: string, right: string): string;
    /**
     * Removes a specific prefix from the start of the string.
     *
     * @example
     * ManipulationMaster.chompLeft('HelloWorld', 'Hello'); // 'World'
     *
     * @param input The input string.
     * @param prefix The prefix to remove.
     * @returns The string without the prefix.
     */
    static chompLeft(input: string, prefix: string): string;
    /**
     * Removes a specific suffix from the end of the string.
     *
     * @example
     * ManipulationMaster.chompRight('HelloWorld', 'World'); // 'Hello'
     *
     * @param input The input string.
     * @param suffix The suffix to remove.
     * @returns The string without the suffix.
     */
    static chompRight(input: string, suffix: string): string;
    /**
     * Removes all characters except for letters and numbers.
     *
     * @example
     * ManipulationMaster.removeNonAlphaNumeric('Hello, World! 123'); // 'HelloWorld123'
     *
     * @param input The input string.
     * @returns The string with only alphanumeric characters.
     */
    static removeNonAlphaNumeric(input: string): string;
    /**
     * Truncates the string to a specified length and adds an ellipsis if necessary.
     *
     * @example
     * ManipulationMaster.truncate('This is a long string', 10); // 'This is a...'
     *
     * @param input The input string.
     * @param length The maximum length of the string.
     * @returns The truncated string with an ellipsis if necessary.
     */
    static truncate(input: string, length: number): string;
    /**
     * Replaces all occurrences of a target string with another string.
     *
     * @example
     * ManipulationMaster.replaceAll('foo bar foo', 'foo', 'baz'); // 'baz bar baz'
     *
     * @param input The input string.
     * @param target The string to be replaced.
     * @param replacement The string to replace with.
     * @returns The modified string.
     */
    static replaceAll(input: string, target: string, replacement: string): string;
    /**
     * Reverses the string.
     *
     * @example
     * ManipulationMaster.reverse('abc'); // 'cba'
     *
     * @param input The input string.
     * @returns The reversed string.
     */
    static reverse(input: string): string;
    /**
     * Extracts the first N characters, or the last N characters if N is negative.
     *
     * @example
     * ManipulationMaster.getLeft('HelloWorld', 5); // 'Hello'
     * ManipulationMaster.getLeft('HelloWorld', -5); // 'World'
     *
     * @param input The input string.
     * @param N The number of characters to extract.
     * @returns The extracted string.
     */
    static getLeft(input: string, N: number): string;
    /**
     * Extracts the last N characters, or the first N if N is negative.
     *
     * @example
     * ManipulationMaster.getRight('HelloWorld', 5); // 'World'
     * ManipulationMaster.getRight('HelloWorld', -5); // 'Hello'
     *
     * @param input The input string.
     * @param N The number of characters to extract.
     * @returns The extracted string.
     */
    static getRight(input: string, N: number): string;
    /**
     * Removes all occurrences of specified characters.
     *
     * @example
     * ManipulationMaster.removeAll('Hello World', ' ', 'l'); // 'HeoWord'
     *
     * @param input The input string.
     * @param chars The characters to remove.
     * @returns The modified string.
     */
    static removeAll(input: string, ...chars: string[]): string;
    /**
     * Converts a string into an array of lines, normalizing newlines (Windows to Unix).
     * @example ManipulationMaster.lines('Hello\r\nWorld\r\n!'); // ['Hello', 'World', '!']
     */
    static lines(input: string): string[];
    /**
     * Removes punctuation from the string.
     * @example ManipulationMaster.stripPunctuation('Hello, world!'); // 'Hello world'
     */
    static stripPunctuation(input: string): string;
    /**
     * Ensures that the string starts with the specified prefix. If not, it prepends the prefix.
     * @example CheckMaster.ensureLeft('world', 'hello '); // 'hello world'
     */
    static ensureLeft(input: string, prefix: string): string;
    /**
     * Ensures that the string ends with the specified suffix. If not, it appends the suffix.
     * @example CheckMaster.ensureRight('hello', ' world'); // 'hello world'
     */
    static ensureRight(input: string, suffix: string): string;
    /**
     * Converts non-Latin characters in the string to their Latin equivalents based on the latin_map.
     *
     * @returns A new string with non-Latin characters replaced.
     * @example
     * const result = ManipulationMaster.latinise("Olá, mundo!"); // "Ola, mundo!"
     */
    static latinise(input: string): string;
    /**
     * This function adds ordinalize support to every String object.
     * @param str The subject string.
     * @returns Return all found numbers their sequence like '22nd'.
     * @example
     *
     *     const inflection = require( 'inflection' );
     *
     *     inflection.ordinalize( 'the 1 pitch' ); // 'the 1st pitch'
     */
    static ordinalize(str: string): string;
}
