export declare class SearchMaster {
    /**
     * Finds the index of the first occurrence of a substring.
     *
     * @param input - The string to search within.
     * @param substring - The substring to find.
     * @returns The index of the first occurrence of the substring, or -1 if not found.
     * @example
     * const index = SearchMaster.indexOf('Hello, world!', 'world');
     * console.log(index); // Output: 7
     */
    static indexOf(input: string, substring: string): number;
    /**
     * Finds the index of the last occurrence of a substring.
     *
     * @param input - The string to search within.
     * @param substring - The substring to find.
     * @returns The index of the last occurrence of the substring, or -1 if not found.
     * @example
     * const index = SearchMaster.lastIndexOf('Hello, world! world!', 'world');
     * console.log(index); // Output: 13
     */
    static lastIndexOf(input: string, substring: string): number;
    /**
     * Finds the nth occurrence of a substring in a string.
     *
     * @param input - The string to search within.
     * @param substring - The substring to find.
     * @param occurrence - The nth occurrence to find (1-based index).
     * @returns The index of the nth occurrence, or -1 if not found.
     * @example
     * const nthIndex = SearchMaster.nthIndexOf('abcabcabc', 'abc', 2);
     * console.log(nthIndex); // Output: 3
     */
    static nthIndexOf(input: string, substring: string, occurrence: number): number;
    /**
     * Finds all matches of a regular expression pattern in a string.
     *
     * @param input - The string to search within.
     * @param pattern - The regular expression pattern to match.
     * @returns An array of matches found, or an empty array if no matches are found.
     * @example
     * const matches = SearchMaster.matchAll('Hello 123, world 456!', /\d+/g);
     * console.log(matches); // Output: ['123', '456']
     */
    static matchAll(input: string, pattern: RegExp): string[];
    /**
     * Finds and returns the first word in a string that matches a regular expression.
     *
     * @param input - The string to search within.
     * @param pattern - The regular expression pattern to match.
     * @returns The first matching word, or an empty string if no match is found.
     * @example
     * const firstMatch = SearchMaster.findFirst('Hello 123 world', /\d+/);
     * console.log(firstMatch); // Output: '123'
     */
    static findFirst(input: string, pattern: RegExp): string;
    /**
     * Performs a fuzzy search to find strings that approximately match the query.
     *
     * @param input - The string to search within.
     * @param query - The substring to match approximately.
     * @param maxDistance - Maximum edit distance allowed (default is 2).
     * @returns An array of matched substrings that are within the specified distance.
     * @example
     * const results = SearchMaster.fuzzySearch('Hello, wrld!', 'world', 1);
     * console.log(results); // Output: ['wrld']
     */
    static fuzzySearch(input: string, query: string, maxDistance?: number): string[];
    /**
     * Highlights all occurrences of a substring by wrapping them in a specified tag.
     *
     * @param input - The string to search within.
     * @param substring - The substring to highlight.
     * @param tag - The HTML tag or format to wrap around matches (default is `<mark>`).
     * @returns The modified string with highlights.
     * @example
     * const highlighted = SearchMaster.highlight('Hello, world!', 'world');
     * console.log(highlighted); // Output: 'Hello, <mark>world</mark>!'
     */
    static highlight(input: string, substring: string, tag?: string): string;
    /**
     * Finds words near each other within a specified distance in a string.
     *
     * @param input - The string to search within.
     * @param word1 - The first word to find.
     * @param word2 - The second word to find.
     * @param maxDistance - The maximum number of words between them.
     * @returns `true` if the words are found within the specified distance, otherwise `false`.
     * @example
     * const proximity = SearchMaster.proximitySearch('The quick brown fox jumps over the lazy dog', 'fox', 'dog', 5);
     * console.log(proximity); // Output: true
     */
    static proximitySearch(text: string, word1: string, word2: string, maxDistance: number): boolean;
}
