/**
 * SimilarityMaster provides mechanisms for checking similarity between strings.
 */
export declare class SimilarityMaster {
    private elements;
    constructor(strings?: string[]);
    /**
     * Check if the collection contains any string similar to the target up to the provided threshold.
     * @param target - The string to compare against the collection elements.
     * @param threshold - The minimum similarity score required for a match.
     * @param includeExactMatches - Whether to include exact matches (default is true).
     * @returns True if the collection contains a similar string; otherwise, false.
     * @example
     * const sm = new SimilarityMaster(['apple', 'banana', 'grape']);
     * sm.hasSimilarString('apples', 0.8); // Returns true if the similarity is above 0.8
     */
    hasSimilarString(target: string, threshold: number, includeExactMatches?: boolean): boolean;
    /**
     * Get all similarity scores for the target string against the collection elements.
     * @param target - The string to compare against.
     * @param algorithm - The algorithm to use for calculating similarity.
     * @returns An array of objects with each collection element and its similarity score.
     * @example
     * const sm = new SimilarityMaster(['apple', 'banana', 'grape']);
     * sm.getSimilarStrings('apple', 'dice'); // Returns array with similarity scores for each element
     */
    getSimilarStrings(target: string, algorithm?: 'dice' | 'levenshtein' | 'jaccard'): Array<{
        element: string;
        similarity: number;
    }>;
    /**
     * Calculates the similarity between two strings using a specified algorithm.
     * @param source - The source string.
     * @param target - The target string to compare against.
     * @param algorithm - The algorithm to use ('dice', 'levenshtein', or 'jaccard').
     * @returns The similarity score based on the chosen algorithm.
     * @example
     * SimilarityMaster.calculateSimilarity('apple', 'apples', 'levenshtein'); // Returns similarity score
     */
    static calculateSimilarity(source: string, target: string, algorithm?: 'dice' | 'levenshtein' | 'jaccard' | 'jaro-winkler'): number;
    /**
     * Computes the Dice Coefficient similarity between two strings.
     */
    private static diceCoefficient;
    /**
     * Computes the Levenshtein Distance between two strings.
     */
    private static levenshteinDistance;
    /**
     * Computes the Jaccard Index similarity between two strings using bigrams.
     */
    private static jaccardIndex;
    /**
     * Computes the Jaro-Winkler similarity between two strings.
     * @param source - The first string.
     * @param target - The second string.
     * @returns The Jaro-Winkler similarity score between the two strings.
     * @example
     * const similarity = SimilarityMaster.jaroWinkler('hello', 'hallo');
     * console.log(similarity); // Output: 0.944
     */
    static jaroWinkler(source: string, target: string): number;
    /**
     * Compares multiple strings to a source string for similarity scoring.
     * @param source - The source string.
     * @param targets - The strings to compare to the source.
     * @param algorithm - The algorithm to use for comparison.
     * @returns An object containing all ratings, the best match, and its index.
     * @example
     * SimilarityMaster.compareMultipleStrings('apple', ['apples', 'banana'], 'jaccard');
     */
    static compareMultipleStrings(source: string, targets: string[], algorithm?: 'dice' | 'levenshtein' | 'jaccard'): {
        ratings: Array<{
            target: string;
            rating: number;
        }>;
        bestMatch: {
            target: string;
            rating: number;
        } | null;
        bestMatchIndex: number;
    };
}
